Context

Struct Context 

pub struct Context(/* private fields */);
A structure that holds several CompiledProgramAnalysers which are used to analyse one or more compiled Yarn programs with Dialogue::analyse. To get the analysis results, call Context::finish_analysis afterwards.

Implementations

Source

impl Context

pub fn empty() -> Context

Creates a new empty Context with no analysers.

pub fn default_analysers() -> Context

Sets up a Context with the default analysers. These are:

pub fn add_analyser(self, analyser: Box<dyn CompiledProgramAnalyser>) -> Context

Adds an analyser to the Context.

pub fn finish_analysis(&self) -> Vec<Diagnosis>

Collects the diagnoses from all analysers in the Context that were previously used with Dialogue::analyse.