pub struct Context(/* private fields */);Expand description
A structure that holds several CompiledProgramAnalysers which are used to analyse one or more compiled Yarn programs with Dialogue::analyse.
To get the analysis results, call Context::finish_analysis afterwards.
Implementations
Sourceimpl Context
impl Context
Sourcepub fn default_analysers() -> Context
pub fn default_analysers() -> Context
Sets up a Context with the default analysers. These are:
- Variable Lister: Adds a
DiagnosisSeverity::Notediagnosis for each variable in the program. - Unused Variable Checker: Adds a
DiagnosisSeverity::Warningdiagnosis for each unused variable in the program.
Sourcepub fn add_analyser(self, analyser: Box<dyn CompiledProgramAnalyser>) -> Context
pub fn add_analyser(self, analyser: Box<dyn CompiledProgramAnalyser>) -> Context
Adds an analyser to the Context.
Sourcepub fn finish_analysis(&self) -> Vec<Diagnosis>
pub fn finish_analysis(&self) -> Vec<Diagnosis>
Collects the diagnoses from all analysers in the Context that were previously used with Dialogue::analyse.